Package: CSSQ
Title: Chip-seq Signal Quantifier Pipeline
Version: 1.24.0
Author: Ashwath Kumar [aut], Michael Y Hu [aut], Yajun Mei [aut], Yuhong Fan [aut]
Maintainer: Fan Lab at Georgia Institute of Technology <yuhong.fan@biology.gatech.edu>
Description: This package is desgined to perform statistical analysis to
    identify statistically significant differentially bound regions between
    multiple groups of ChIP-seq dataset. 
License: Artistic-2.0
Encoding: UTF-8
biocViews: ChIPSeq, DifferentialPeakCalling, Sequencing, Normalization
Depends: SummarizedExperiment, GenomicRanges, IRanges, S4Vectors,
        rtracklayer
Imports: GenomicAlignments, GenomicFeatures, Rsamtools, ggplot2,
        grDevices, stats, utils
Suggests: BiocStyle, knitr, rmarkdown, markdown
VignetteBuilder: knitr
RoxygenNote: 7.0.0
git_url: https://git.bioconductor.org/packages/CSSQ
git_branch: RELEASE_3_23
git_last_commit: e7dea6b
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:30:01 UTC; biocbuild
