# Generated by roxygen2: do not edit by hand

export(DBAnalyze)
export(ansTransform)
export(getBgSubVal)
export(getRegionCounts)
export(kmeansNormalize)
export(loadCountData)
export(normalizeData)
export(plotDist)
export(preprocessData)
import(GenomicAlignments)
import(GenomicFeatures)
import(GenomicRanges)
import(IRanges)
import(Rsamtools)
import(SummarizedExperiment)
import(ggplot2)
import(rtracklayer)
importFrom(S4Vectors,DataFrame)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(stats,kmeans)
importFrom(stats,p.adjust)
importFrom(utils,combn)
importFrom(utils,read.table)
